<?php
class ControllerExtensionModuleMMA extends Controller {
	private $error = array();

	public function uninstall() {
		$this->load->model('extension/module/mma');
		$this->model_extension_module_mma->uninstall();
	}

	public function install() {		
		$this->load->model('extension/module/mma');
		$this->model_extension_module_mma->install();	
	}

	public function index() {
		$this->load->language('extension/module/mma');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->document->addStyle('../catalog/view/javascript/jquery/swiper/css/swiper.min.css');
		$this->document->addStyle('../catalog/view/javascript/jquery/swiper/css/opencart.css');
		$this->document->addScript('../catalog/view/javascript/jquery/swiper/js/swiper.jquery.js');

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->model_setting_setting->editSetting('module_mma', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true));
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/module/mma', 'user_token=' . $this->session->data['user_token'], true)
		);

		$this->load->model('tool/image');
		
		$data['thumb'] = $this->model_tool_image->resize('no_image.png', 100, 100);
		$data['thumb_img'] = 'no_image.png';

		$this->load->model('localisation/language');

		$data['languages'] = $this->model_localisation_language->getLanguages();

		$data['action'] = $this->url->link('extension/module/mma', 'user_token=' . $this->session->data['user_token'], true);

		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true);

		foreach (['module_mma_status', 'module_mma_about_status', 'module_mma_address', 'module_mma_email', 'module_mma_phone', 'module_mma_desc_status', 'module_mma_desc_text', 'module_mma_sub_mail_text', 'module_mma_sub_mail_subject_text', 'module_mma_logo_status', 'module_mma_logo_width', 'module_mma_social_status', 'module_mma_facebook_url', 'module_mma_twitter_url', 'module_mma_pinterest_url', 'module_mma_tumblr_url', 'module_mma_youtube_url', 'module_mma_instagram_url','module_mma_subscribe_status', 'module_mma_subscribe_form_title', 'module_mma_subscribe_form_button', 'module_mma_subscribe_maintenance_title', 'module_mma_body_bg', 'module_mma_footer_bg', 'module_mma_custom_css', 'module_mma_image', 'module_mma_logo_image', 'module_mma_logo_height'] as $key) {
			if (isset($this->request->post[$key])) {
				$data[$key] = $this->request->post[$key];
			} else {
				$data[$key] = $this->config->get($key);
			}
		}
		
		foreach (['module_mma_image', 'module_mma_logo_image'] as $key) {
		 	if (isset($this->request->post[$key])) {
				$data[$key . '_thumb'] = $this->model_tool_image->resize($this->request->post[$key], 100, 100);
			} else {
				$data[$key . '_thumb'] = $this->model_tool_image->resize($this->config->get($key), 100, 100);
			}   
		}

		$this->load->model('extension/module/mma');
		$data['subscribers'] = $this->model_extension_module_mma->getSubscribers();		
		$data['total_subscribers'] = $this->model_extension_module_mma->totalSubscribers();		
		$data['user_token'] = $this->session->data['user_token'];
		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['otherhtml'] = $this->getURLS();
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/mma', $data));
	}

	public function sendmailtoall() {
		$json = [];
		$json['status'] = false;
		$json['message'] = '';		

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->load->language('extension/module/mma');
			$this->load->model('extension/module/mma');
			
			$subscribers = $this->model_extension_module_mma->getSubscribers();

			$this->load->model('setting/store');

			$store_name = html_entity_decode($this->config->get('config_name'), ENT_QUOTES, 'UTF-8');

			foreach ($subscribers as $subscriber) {
				if($subscriber['is_mail_sent'] == 0) {
					$mail_subject = $mail_text = '';
					if($this->config->get('module_mma_sub_mail_text')[$subscriber['locale']]	) {
						$mail_text = $this->config->get('module_mma_sub_mail_text')[$subscriber['locale']];
						$mail_subject = $this->config->get('module_mma_sub_mail_subject_text')[$subscriber['locale']];
					} else {
						$json['status'] = false;
						$json['message'] = $this->language->get('text_error_send_mail');
						break;
					}

					$mail = new Mail($this->config->get('config_mail_engine'));
					$mail->parameter = $this->config->get('config_mail_parameter');
					$mail->smtp_hostname = $this->config->get('config_mail_smtp_hostname');
					$mail->smtp_username = $this->config->get('config_mail_smtp_username');
					$mail->smtp_password = html_entity_decode($this->config->get('config_mail_smtp_password'), ENT_QUOTES, 'UTF-8');
					$mail->smtp_port = $this->config->get('config_mail_smtp_port');
					$mail->smtp_timeout = $this->config->get('config_mail_smtp_timeout');
				
					$mail->setTo($subscriber['email']);
					$mail->setFrom($this->config->get('config_email'));
					$mail->setSender($store_name);
					$mail->setSubject(html_entity_decode($mail_subject));
					$mail->setText(html_entity_decode($mail_text));
					
					if($mail->send()) {
						$this->model_extension_module_mma->updateSubscriber($subscriber['mma_id']);
					}
				}

				$json['status'] = true;
				$json['message'] = $this->language->get('text_success_send_mail');
			}

		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}

	public function delete() {
		$json = [];
		$json['status'] = false;
		$json['message'] = '';		

		if (($this->request->server['REQUEST_METHOD'] == 'DELETE') && $this->validate()) {
			$this->load->language('extension/module/mma');
			$this->load->model('extension/module/mma');
			
			$this->model_extension_module_mma->deleteSubscriber($this->request->get['subscriber_id']);		
			$json['status'] = true;
			$json['message'] = $this->language->get('delete_subscriber');
		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));	
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/module/mma')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		return !$this->error;
	}

	public function getURLS() {
		if($this->cache->get('mymods')) {
			return $this->cache->get('mymods');
		}

		$this->load->language('extension/module/mma');
		
		$host = isset($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : (isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '');
		
		$data = file_get_contents('https://codeeshop.com/index.php?ajax=1&fc=module&module=ps_bestsellers&controller=Bestselling&action=get&m=' . urlencode($this->language->get('heading_title')) . '&origin=' . urlencode($host));

		$json = json_decode($data, true);
		$this->cache->set('mymods', $json);

		return $json;
	}
}